<template>
  <div class="supplier">
    <div class="top">
      <div class="filter">
        <div class="filter-card">
          <CommonSearch
            :show-add="true"
            add-title="新建"
            @addCommonClick="addBtnClick"
            :show-download="true"
            :amount-view="false"
            :show-action-btn="false"
            :placeholder="'请输入供应商名称'"
            @searchClick="onFilterSearch"
          />
        </div>
      </div>
      <div class="body">
        <div class="body-card">
          <div class="list-view">
            <TableCommonView
              ref="tableSupplier"
              :table-list="tableList"
              @selCommonClick="selCommonClick"
              @selTableCol="selTableCol"
              @tableRowClick="tableRowClick"
              :selectClassRow="selectRow"
            >
              <template slot="tableButton">
                <el-table-column label="操作" width="100">
                  <template slot-scope="scope">
                    <el-button
                      v-if="scope.row.status === 0"
                      @click="enableClick(scope.row, '启用')"
                      type="text"
                      size="small"
                      >启用</el-button
                    >
                    <el-button v-else @click="enableClick(scope.row, '停用')" type="text" size="small">停用</el-button>
                    <el-button @click="modifyClick(scope.row)" type="text" size="small">修改</el-button>
                  </template>
                </el-table-column>
              </template>
            </TableCommonView>
          </div>
          <div class="btn-pager">
            <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
          </div>
        </div>
      </div>
    </div>
    <div class="bottom">
      <div class="simple-filter">
        <div class="simple-filter-card">
          <CommonSearch
            :show-add="false"
            :show-download="false"
            :amount-view="false"
            :show-screen="false"
            :show-action-btn="false"
            :placeholder="'请输入产品名称/产品规格/产品编码'"
            @searchClick="onProductFilterSearch"
          >
            <template slot="leftButton">
              <div class="sub-title"><span class="sub-title-decorator"></span>可提供的产品</div>
              <el-button type="primary" size="mini" @click="creatPurchase">创建采购单</el-button>
            </template>
            <template slot="rightButton">
              <el-button type="primary" size="mini" @click="addNewProductClick">添加新产品</el-button>
            </template>
          </CommonSearch>
        </div>
      </div>
      <div class="body">
        <div class="body-card">
          <div class="list-view">
            <TableCommonView
              ref="tableListProduct"
              :table-list="productTableList"
              @selCommonClick="selCommonClick"
              @getSelectArray="getSelectArray"
              @selTableCol="selProductTableCol"
            >
              <template slot="tableButton">
                <el-table-column label="操作" width="170">
                  <template slot-scope="scope">
                    <el-button @click="raleteClick(scope.row)" type="text" size="small">相关供应商</el-button>
                    <el-button @click="editClick(scope.row)" type="text" size="small">修改</el-button>
                    <el-button @click="delClick(scope.row)" type="text" size="small">删除</el-button>
                  </template>
                </el-table-column>
              </template>
            </TableCommonView>
          </div>
          <div class="btn-pager">
            <PagerView
              class="page"
              :pager-options="productPagerOptions"
              @size-change="productChangeHandler"
              @current-change="currentProductHandler"
            />
          </div>
        </div>
      </div>
    </div>
    <!-- 新建/编辑销售线索 -->
    <AddSupplier v-if="editConfig.visible" :add-common-config="editConfig" />
    <!-- 详情 -->
    <DetailSupplier v-if="commonDetail.visible" :common-detail="commonDetail" />
    <!-- 相关供应商 -->
    <RaleteSupplierList v-if="raleteSupplierConfig.visible" :common-config="raleteSupplierConfig" />
    <!-- 添加新产品 -->
    <AddNewProduct v-if="newProductConfig.visible" :add-common-config="newProductConfig" />
    <!-- 新建/编辑 -->
    <AddPurchase v-if="editPurchaseConfig.visible" :edit-common-config="editPurchaseConfig" />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import { getSupplierList, changeSupplierStatus } from "@/api/supplierManage/supplier"
import { getPurchaseList } from "@/api/purchaseManage/purchase"
import DetailSupplier from "@/views/supplierManage/supplier/DetailSupplier"
import AddSupplier from "@/views/supplierManage/supplier/AddSupplier"
import RaleteSupplierList from "@/views/supplierManage/supplier/RaleteSupplierList"
import AddNewProduct from "@/views/supplierManage/supplier/AddNewProduct"
import { getProductListTwo, deleteProduct } from "@/api/productManage/product"
import AddPurchase from "@/views/purchaseManage/purchase/components/AddPurchase"

export default {
  name: "SupplierManage",
  props: {},
  components: { DetailSupplier, AddSupplier, RaleteSupplierList, AddNewProduct, AddPurchase },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      searchSupplierName: "",
      tableList: {}, // 供应商列表
      productTableList: {}, // 产品列表
      selValueList: [],
      searchOptions: [],
      searchProductOptions: [], // 产品查询
      commonDetail: {
        visible: false,
        infomation: {},
        productListInfo: []
      },
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      raleteSupplierConfig: {
        visible: false,
        infomation: {}
      },
      newProductConfig: {
        visible: false,
        title: "添加",
        infomation: {}
      },
      productPagerOptions: {
        currPage: 1,
        pageSize: 10,
        totalCount: 0
      },
      supplierId: 0,
      showCol: ["供应商编号", "供应商名称", "供应商类型", "所属行业", "联系人", "联系电话", "状态"],
      tableColumn: [
        { label: "供应商编号", prop: "number", min: 190, isCommonClick: true },
        { label: "供应商名称", prop: "name", min: 130, default: true },
        { label: "供应商类型", prop: "supplierType", min: 130 },
        { label: "所属行业", prop: "industry", min: 130 },
        { label: "联系人", prop: "contact", min: 130 },
        { label: "联系电话", prop: "phone", min: 130 },
        { label: "状态", prop: "status_name", min: 130 },
        { label: "创建时间", prop: "created_at", min: 130 }
      ],
      showProductCol: ["产品编码", "产品名称", "产品规格", "单位", "采购价格", "供货时长(天)", "物流时长(天)"],
      productColumn: [
        { label: "产品编码", prop: "number", min: 190 },
        { label: "产品名称", prop: "name", min: 130, default: true },
        { label: "产品规格", prop: "specifications", min: 130 },
        { label: "单位", prop: "unit", min: 130 },
        { label: "采购价格", prop: "purchasePrice", min: 130 },
        { label: "供货时长(天)", prop: "deliveryTime", min: 130 },
        { label: "物流时长(天)", prop: "shippingDuration", min: 130 }
      ],
      editPurchaseConfig: {
        // 创建采购
        visible: false,
        title: "创建",
        infomation: {
          supplierName: ""
        }
      },
      selectRow: {}
    }
  },
  created() {
    this.setTable()
    this.setProductTable()
    this.getData()
  },
  methods: {
    setColumnVisible(showCol) {
      return this.tableColumn.map((ele) => {
        return {
          ...ele,
          isShowColumn: showCol.includes(ele.label)
        }
      })
    },
    setProductColumnVisible(showCol) {
      return this.productColumn.map((ele) => {
        return {
          ...ele,
          isShowColumn: showCol.includes(ele.label)
        }
      })
    },
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectIndex: true,
        highlight: true,
        ref: "tableListRef",
        showcol: this.showCol,
        allcol: [],
        tableColumn: this.setColumnVisible(this.showCol)
      }
      this.tableList.allcol = this.tableList.tableColumn.filter((ele) => !ele.default).map((ele) => ele.label)

      this.searchOptions = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        const label = this.tableList.tableColumn[i].label
        const value = this.tableList.tableColumn[i].prop
        this.searchOptions.push({ value: value, label: label })
      }
    },
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setColumnVisible(val)
    },
    setProductTable() {
      this.productTableList = {
        tableInfomation: [],
        selectBox: true,
        selectIndex: true,
        showcol: this.showProductCol,
        allcol: [],
        tableColumn: this.setProductColumnVisible(this.showProductCol)
      }
      this.searchProductOptions = []
      for (let i = 0; i < this.productTableList.tableColumn.length; i++) {
        const label = this.productTableList.tableColumn[i].label
        const value = this.productTableList.tableColumn[i].prop
        this.searchProductOptions.push({ value: value, label: label })
      }

      this.productTableList.allcol = this.productTableList.tableColumn
        .filter((ele) => !ele.default)
        .map((ele) => ele.label)
      console.log("this.productTableList", this.productTableList)
    },
    selProductTableCol(val) {
      this.showProductCol = val
      this.productTableList.tableColumn = this.setProductColumnVisible(val)
    },
    // 请求数据
    getData() {
      this.getSupplierList()
    },
    // 供应商列表
    async getSupplierList() {
      await getSupplierList({
        name: this.searchSupplierName,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      }).then((res) => {
        console.log(res)
        if (res.code === 200) {
          const list = res.data.list.map((item) => {
            return {
              ...item,
              id: item.id,
              status_name: item.status === 0 ? "未启用" : "启用"
            }
          })
          console.log(list)
          this.tableList.tableInfomation = list || []
          this.pagerOptions.totalCount = res.data.total
          if (list && list.length > 0) {
            this.supplierId = this.tableList.tableInfomation[0].id
            this.selectRow = this.tableList.tableInfomation.length > 0 ? this.tableList.tableInfomation[0] : {}
          } else {
            this.supplierId = 0
          }
          // this.$nextTick(() => {
          //   this.$refs.tableSupplier.$refs.table.setCurrentRow(this.tableList.tableInfomation[0])
          // })

          // 重新获取供应商列表后应该重置产品列表页码
          this.productPagerOptions.currPage = 1
          // 如果供应商列表为空,则可提供产品列表也应为空
          if (list.length) {
            this.getProductList()
          } else {
            this.productTableList.tableInfomation = []
            this.productPagerOptions.currPage = 1
            this.productPagerOptions.totalCount = 0
          }
        }
      })
    },
    // 产品列表
    async getProductList(val, content) {
      console.log(val, content)
      await getProductListTwo({
        [val]: content,
        supplierId: this.supplierId,
        page: this.productPagerOptions.currPage,
        pageSize: this.productPagerOptions.pageSize
      }).then((res) => {
        let list = res.data.list.map((item) => {
          return {
            ...item
          }
        })
        this.productTableList.tableInfomation = list || []
        this.productPagerOptions.totalCount = res.data.total
      })
    },
    // 搜索供应商
    onFilterSearch(searchText) {
      this.searchSupplierName = searchText ?? ""
      this.pagerOptions.currPage = 1
      this.getSupplierList()
    },
    // 搜索产品
    onProductFilterSearch(searchText) {
      this.productPagerOptions.currPage = 1
      this.getProductList("keyword", searchText)
    },
    // 新建供应商
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      this.editConfig.infomation = {
        fileId: 0,
        responsiblePersonName: document.cookie.replace(/(?:(?:^|.*;\s*)username\s*=\s*([^;]*).*$)|^.*$/, "$1")
      }
    },
    // 启用供应商
    async enableClick(row, value) {
      let status = value === "启用" ? 1 : 0
      await changeSupplierStatus({
        id: Number(row.id),
        status: status
      }).then((res) => {
        if (res.code === 200) {
          this.$message.success("状态修改成功")
          this.getData()
        }
      })
    },
    // 修改供应商
    modifyClick(row) {
      this.editConfig.visible = true
      this.editConfig.title = "修改"
      this.editConfig.infomation = { ...row, file_name: row.contract.fileName }
    },
    // 相关供应商
    raleteClick(row) {
      console.log(row)
      this.raleteSupplierConfig.visible = true
      this.raleteSupplierConfig.infomation = { ...row }
    },
    // 添加新产品
    addNewProductClick() {
      this.newProductConfig.visible = true
      this.newProductConfig.title = "添加"
      this.newProductConfig.infomation = { supplierId: this.supplierId }
    },
    // 修改产品
    editClick(row) {
      this.newProductConfig.visible = true
      this.newProductConfig.title = "修改"
      this.newProductConfig.infomation = { ...row }
    },
    // 删除
    delClick(row) {
      this.$confirm("是否确认删除?", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          deleteProduct({ id: row.id }).then((response) => {
            if (response.code === 200) {
              this.$message.success("删除成功")
              this.getProductList()
            } else {
              this.$message.warning("删除失败")
            }
          })
        })
        .catch(() => {})
    },
    getSelectArray(val) {
      console.log(val)
      this.selValueList = []
      const list = val.map((item) => {
        return item.id
      })
      this.selValueList = list
    },
    tableRowClick(row) {
      this.productPagerOptions.currPage = 1
      this.selectRow = row
      this.supplierId = row.id
      this.getProductList()
    },
    // 详情
    async selCommonClick(row) {
      await getPurchaseList({ pageSize: 10, page: 1, supplierId: Number(row.id) }).then((res) => {
        this.commonDetail.productListInfo = res.data.list
      })
      this.commonDetail.visible = true
      this.commonDetail.infomation = { ...row }
    },
    // 产品列表翻页
    productChangeHandler(val) {
      this.productPagerOptions.currPage = 1
      this.productPagerOptions.pageSize = val
      this.getProductList()
    },
    currentProductHandler(val) {
      this.productPagerOptions.currPage = val
      this.getProductList()
    },
    // 创建采购单
    creatPurchase() {
      this.editPurchaseConfig.visible = true
      this.editPurchaseConfig.title = "新建"
      this.editPurchaseConfig.infomation = {
        supplierId: this.selectRow.id,
        purchaseTypeId: "2",
        supplierName: this.selectRow.name
      }
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.supplier {
  height: 100%;
  overflow: hidden;
  .top {
    position: relative;
    height: 55%;
    .body {
      position: relative;
      height: calc(100% - 92px);
    }
  }
  .bottom {
    position: relative;
    height: 45%;
    .body {
      position: relative;
      height: calc(100% - 40px);
      padding-top: 0;
    }
  }
  .filter {
    height: 80px;
    display: flex;
    align-items: center;
    padding: 12px 20px 0 20px;
    &-card {
      height: 80px;
      display: flex;
      align-items: center;
      box-sizing: border-box;
      padding: 10px 20px;
      flex: 1;
      border-radius: 12px;
      background-color: #fff;
    }
  }
  .simple-filter {
    height: 40px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    padding: 0 20px;
    &-card {
      height: 80px;
      display: flex;
      align-items: center;
      box-sizing: border-box;
      flex: 1;
    }
  }
  .body {
    box-sizing: border-box;
    padding: 10px 20px;
    border-radius: 12px;
    .body-card {
      background-color: #fff;
      border-radius: 12px;
      height: 100%;
      overflow: hidden;
    }

    .supplier-search {
      display: flex;
      align-items: center;
      .add-view {
        margin-left: auto;
        margin-right: 20px;
      }
    }
    .list-view {
      height: calc(100% - 60px);
      overflow: hidden;
    }
    .btn-pager {
      display: flex;
      .page {
        margin-left: auto;
      }
    }
  }
}
.sub-title {
  flex-shrink: 0;
  margin-right: 20px;
  font-size: 16px;
  font-weight: bold;
  height: 28px;
  line-height: 28px;
  position: relative;
  padding-left: 12px;
  &-decorator {
    position: absolute;
    height: 100%;
    width: 4px;
    background-color: #2a78fb;
    top: 0;
    left: 0;
  }
}
</style>
